import { menuData } from './UserMenuData';
import request, { authRequest } from '/@/utils/request';

/**
 * （不建议写成 request.post(xxx)，因为这样 post 时，无法 params 与 data 同时传参）
 *
 * 登录api接口集合
 * @method signIn 用户登录
 * @method signOut 用户退出登录
 */
export function useLoginApi() {
	return {
		signIn: (data: object) => {
			return request({
				url: '/user/signIn',
				method: 'post',
				data,
			});
		},
		signOut: (data: object) => {
			return request({
				url: '/user/signOut',
				method: 'post',
				data,
			});
		},
	};
}

/**
 *
 * @summary 获取验证码
 */
export async function apiSysAuthCaptchaGet(params: any) {
	return request({
		url: '/Auth/Tool/GetCaptcha@V1.0',
		method: 'GET',
		params: params,
	});
}
/**
 *
 * @summary 校验验证码
 */
export async function apiSysAuthCaptchaRuleGet(params: any) {
	return request({
		url: '/Auth/Tool/VerifyCaptcha@V1.0',
		method: 'GET',
		params: params,
	});
}
/**
 *
 * @summary 获取登录配置
 */
export async function apiSysAuthLoginConfigGet(options: any) {
	return new Promise((resolve, reject) => {
		// SysAuthApiFp(this.configuration).apiSysAuthLoginConfigGet(options).then(res=>{
		const res = {
			code: 200,
			type: 'success',
			message: 'null',
			result: {
				secondVerEnabled: true,
				captchaEnabled: true,
				wartermarkEnabled: true,
			},
			extras: null,
			time: '2023-02-13 17:33:40',
		};
		resolve(res);
		// });
	});
}
/**
 *
 * @summary 登录验证
 */
export async function apiSysAuthLoginPost(params: any) {
	return request({
		url: '/Auth/User/Login/FromStandardBySystem@V1.0',
		method: 'POST',
		data: params,
	});
}
// 获取用户信息
export async function apiSysAuthUserInfoGet() {
	return new Promise((resolve) => {
		const res = {
			data: {
				code: 200,
				type: 'success',
				message: 'null',
				result: {
					account: 'superadmin',
					realName: '超级管理员',
					avatar: null,
					introduction: null,
					address: null,
					signature: 'https://apidemo.devqd.com/Signature/380502566977861.png',
					orgId: 0,
					orgName: null,
					posName: null,
					buttons: [
						'sysTenant:page',
						'sysTenant:update',
						'sysTenant:add',
						'sysTenant:delete',
						'sysTenant:grantMenu',
						'sysTenant:resetPwd',
						'sysTenant:createDb',
						'sysMenu:list',
						'sysMenu:update',
						'sysMenu:add',
						'sysMenu:delete',
						'sysConfig:page',
						'sysConfig:update',
						'sysConfig:add',
						'sysConfig:delete',
						'sysDictType:page',
						'sysDictType:update',
						'sysDictType:add',
						'sysDictType:delete',
						'sysJob:page',
						'sysJob:update',
						'sysJob:add',
						'sysJob:delete',
						'sysCache:keyList',
						'sysCache:delete',
						'sysRegion:page',
						'sysRegion:update',
						'sysRegion:add',
						'sysRegion:delete',
						'sysRegion:sync',
						'sysFile:page',
						'sysFile:upload',
						'sysFile:download',
						'sysFile:delete',
						'sysVislog:page',
						'sysVislog:clear',
						'sysOplog:page',
						'sysOplog:clear',
						'sysOplog:export',
						'sysExlog:page',
						'sysExlog:clear',
						'sysExlog:export',
						'sysDifflog:page',
						'sysDifflog:clear',
						'sysUser:page',
						'sysUser:update',
						'sysUser:add',
						'sysUser:delete',
						'sysUser:detail',
						'sysUser:grantRole',
						'sysUser:resetPwd',
						'sysUser:setStatus',
						'sysUser:changePwd',
						'sysUser:forceOffline',
						'sysRole:page',
						'sysRole:update',
						'sysRole:add',
						'sysRole:delete',
						'sysRole:grantMenu',
						'sysRole:grantData',
						'sysRole:setStatus',
						'sysOrg:list',
						'sysOrg:update',
						'sysOrg:add',
						'sysOrg:delete',
						'sysPos:list',
						'sysPos:update',
						'sysPos:add',
						'sysPos:delete',
						'sysUser:changePwd',
						'sysUser:updateBase',
						'sysUser:signature',
						'sysNotice:page',
						'sysNotice:update',
						'sysNotice:add',
						'sysNotice:delete',
						'sysNotice:public',
						'sysNotice:cancel',
						'weChatUser:page',
						'weChatUser:update',
						'weChatUser:delete',
					],
				},
			},
			extras: null,
			time: '2023-02-13 10:24:37',
		};
		resolve(res);
	});
}

// 退出登录
export async function apiSysAuthLogoutPost() {
	return new Promise((r) => {});
}

/**
 * @summary 获取图片验证码
 */
export const GetCaptcha = async () => {
	return authRequest({
		url: '/Auth/Tool/GetCaptcha@V1.0',
		method: 'GET',
	});
};

/**
 * @summary 检验图片验证码
 */
export const GetVerifyCaptcha = async (params) => {
	return authRequest({
		url: '/Auth/Tool/VerifyCaptcha@V1.0',
		method: 'GET',
		params: params,
	});
};

/**
 * @summary 登录
 */
export const LoginSoftware = async (params) => {
	return authRequest({
		url: '/Auth/User/Login/LoginSoftwareStandardBySystemAccount@V1.0',
		method: 'POST',
		data: params,
	});
};

/**
 * @summary 获取当前用户在当前软件中所有的后端菜单配置(树结构)
 */
export const GetUserMenuTree = async () => {
	return {
		json_ok: true,
		data: menuData,
	};
};

/**
 * @summary 通过 UserID 获取用户角色
 */
export const GetRolesListByUserID = async (params) => {
	return authRequest({
		url: '/Auth/Role/Std/GetByUserID@V1.0',
		method: 'GET',
		params: params,
	});
};
